"""
NucleusIQ Prompts Module

This module provides various prompt engineering techniques.
"""

from nucleusiq.prompts.factory import PromptFactory, PromptTechnique

__all__ = ["PromptFactory", "PromptTechnique"]
